@@ -21,7 +21,13 @@
 
 ;;; Code:
 
-(require 'f)
+
+(setq safe-local-variable-values
+      '((flycheck-disabled-checkers emacs-lisp-checkdoc)))
+
+
+(when (require 'undercover nil t)
+  (undercover "*.el" (:report-type :codecov)))
 
 (add-to-list 'load-path
              (file-name-as-directory (f-parent (f-parent (f-this-file)))))
